@@ -9,23 +9,9 @@ from config import PROJECTNAME
 
 import catalog
 from content.container import HitcounterContainer
-
-from Globals import INSTANCE_HOME
-import os
-HITLOG = os.environ['HITLOG']
-if HITLOG:
-    LOG_FILENAME = HITLOG+ "/stat.log"
-else:
-    LOG_FILENAME = INSTANCE_HOME + "/log/stat.log"
 import logging
-import logging.handlers
 # Set up a specific logger with our desired output level
-logger = logging.getLogger('mcb.stat')
-logger.setLevel(logging.DEBUG)
-# Add the log message handler to the logger
-handler = logging.handlers.RotatingFileHandler(LOG_FILENAME, backupCount=1)
-handler.setFormatter( logging.Formatter("%(asctime)s <> %(message)s") )
-logger.addHandler(handler)
+logger = logging.getLogger('xm.hitcounter')
 
 
 def initialize(context):
